@@ -8,6 +8,7 @@ import time
 import httpx
 import shutil
 import traceback
+import random
 
 
 class DeployOnnxInfer:
@@ -47,11 +48,11 @@ class DeployOnnxInfer:
                 if file.endswith(".onnx"):
                     # 构建完整文件路径
                     src_file_path = os.path.join(dir_path, file)
-                    dst_file_path = os.path.join(self.onnx_weight_path, file)
+                    dst_file_path = os.path.join(self.onnx_weight_path, "best.onnx")
                     # 将文件移动到目标目录
                     shutil.move(src_file_path, dst_file_path)
 
-                if file == "labels.txt":
+                if file == "classes.txt":
                     # 构建完整文件路径
                     src_file_path = os.path.join(dir_path, file)
                     dst_file_path = os.path.join(self.onnx_weight_path, file)
@@ -74,14 +75,19 @@ class DeployOnnxInfer:
     def docker_run(self, port: int) -> str:
         client = docker.from_env()
         client.images.pull(self.docker_image_name)
-        container_name = f"{self.docker_image_name.split(':')[0].split('/')[-1]}-{port}"
-        container_id = client.containers.run(
+        factor = random.randint(1000, 9999)  # 添加随机数避免容器名称重复
+        container_name = f"{self.docker_image_name.split(':')[0].split('/')[-1]}-{factor}-{port}"
+        f"{settings.DEPLOY_TARGET_CONTAINER_WORKDIR}/{settings.DEPLOY_ONNX_WEIGHT_DIR}"
+        bind_dir = os.path.join(settings.DEPLOY_TARGET_CONTAINER_WORKDIR, settings.DEPLOY_ONNX_WEIGHT_DIR)
+        container = client.containers.run(
             image=self.docker_image_name,
             detach=True,  # 是否以后台模式运行
-            volumes={f"/srv/app/{self.onnx_weight_path}": {"bind": f"/srv/app/{settings.DEPLOY_ONNX_WEIGHT_DIR}", "mode": "rw"}},
+            volumes={os.path.join(settings.DEPLOY_HOST_DIR, self.onnx_weight_path): {"bind": bind_dir, "mode": "rw"}},
             ports={"8000/tcp": port},  # 端口映射，这里将容器的80端口映射到主机的8080端口
+            environment={"AUTHENTICATION_TOKEN": self.token, "IS_GPU": self.is_gpu},
             name=container_name,  # 容器名称
         )
+        container_id = container.id
         return container_id
 
     def __call__(self, *args, **kwargs):
